Delft-FIAT Toolbox
------------------
This toolbox contains post-processing scripts for Delft-FIAT_ output.

Installation
====================
To use this package, GDAL has to be installed on your system, which is a c++ library.
A simple way to install GDAL is to use conda. If you do not have conda installed, you can install it by following the instructions on the `conda website <https://docs.conda.io/en/latest/miniconda.html>`_.


After creating and activating your conda environment, you can install GDAL using the following command
    conda install -c conda-forge gdal

Then, you can install fiat toolbox and its dependencies using pip:
    pip install fiat-toolbox


Metrics table writer
====================
This module contains functions to write out custom metrics from Delft-FIAT output. Etc. etc.

Equity tools
==================
This module contains functions to ... 

.. _Delft-FIAT: https://github.com/Deltares/delft-fiat
